<?php

class AdminClass {
    public function __construct() {
        add_action( 'admin_init', [$this, 'register_settings'] );
        add_action( 'admin_menu', [$this, 'add_settings_page'] );
   }

   public function add_settings_page() {
        add_menu_page( 'SF Autosuggest Products', 'SF Autosuggest Products', 'manage_options', 'sf_pa-autosuggest-plugin', [$this, 'render_plugin_settings'], 'dashicons-search' );
    }
    
    public function render_plugin_settings() {
        ?>
        <div class="sf_pa-be-container">
            <h2 class="sf_pa_be-title"><?php _e('SF Autosuggest Products', 'sf_products_autosuggest'); ?></h2>
            <div class="sf_pa_shortcode-banner">
                <?php _e('To show input use this shortcode: <strong>[sf_pa_search]</strong>', 'sf_products_autosuggest'); ?>
            </div>
            <div class="sf_pa-row">
                <div class="sf_pa-col-7">
                    <form action="options.php" method="post">
                        <?php 
                        settings_fields( 'sf_pa_autosuggest_plugin_options' );
                        do_settings_sections( 'sf_pa_autosuggest_plugin' ); ?>
                        <input name="submit" class="button button-primary" type="submit" value="<?php esc_attr_e( 'Save', 'sf_products_autosuggest'); ?>" />
                    </form>
                </div>
                <div class="sf_pa-col-5 sf_pa-image-example">
                    <img src="<?php echo untrailingslashit( plugin_dir_url( __FILE__ ) ).'/../assets/img/search-example.png'; ?>">
                    <p><i><?php _e('Search example image', 'sf_products_autosuggest'); ?></i></p>
                </div>
            </div>
        </div>
        <?php
    }

    public function register_settings() {
        register_setting( 'sf_pa_autosuggest_plugin_options', 'sf_pa_autosuggest_plugin_options', [$this, 'plugin_options_validate'] );
        add_settings_section( 'sf_pa_apparance', __('Customize search input and autosuggest results', 'sf_products_autosuggest'), [$this, 'apparance_intro'], 'sf_pa_autosuggest_plugin' );
    
        $fields_array = array(
                            array(
                                'title' => __('Search results count', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'results_count',
                                'input' => 'text_input',
                                'instruction' => __('Maximum number of products to display', 'sf_products_autosuggest')
    
                            ),
                            array(
                                'title' => __('Text "Show all results"', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'all_text',
                                'input' => 'text_input',
                                'instruction' => __('Text of the element "Show all results"', 'sf_products_autosuggest')
                            ),
                            array(
                                'title' => __('Backgorund color "Show all results"', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'all_bg',
                                'input' => 'color_picker',
                                'instruction' => __('Background color of the element "Show all results"', 'sf_products_autosuggest')
                            ),
                            array(
                                'title' => __('Text color "Show all results"', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'all_color',
                                'input' => 'color_picker',
                                'instruction' => __('Text color of the element "Show all results"', 'sf_products_autosuggest')
                            ),
                            array(
                                'title' => __('Show thumbnails', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'show_thumbnail',
                                'input' => 'checkbox',
                                'instruction' => __('Check if you want to show thumbnails in results', 'sf_products_autosuggest')
                            ),
                            array(
                                'title' => __('Show categories', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'show_cat',
                                'input' => 'checkbox',
                                'instruction' => __('Check if you want to show product category in results', 'sf_products_autosuggest')
                            ),
                            array(
                                'title' => __('Exclude categories from search', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'exclude_cat',
                                'input' => 'text_input',
                                'instruction' => __('Exclude categories from search. Insert comma separated id of categories. For example "12,20"', 'sf_products_autosuggest')
                            ),
                            array(
                                'title' => __('Exclude products from search', 'sf_products_autosuggest'),
                                'section' => 'sf_pa_apparance',
                                'key' => 'exclude_ids',
                                'input' => 'text_input',
                                'instruction' => __('Exclude products from search. Insert comma separated id of products. For example "12,20"', 'sf_products_autosuggest')
                            ),
                        );
    
        foreach($fields_array as $single_field){
            add_settings_field( $single_field['section'].'_'.$single_field['key'], $single_field['title'], [$this, $single_field['input']], 'sf_pa_autosuggest_plugin', $single_field['section'], array('section' => $single_field['section'],'key' => $single_field['key'], 'instruction' => $single_field['instruction']) );
        }
    }

    public function apparance_intro() {
        return '';
    }
    
    public function text_input($params){
        $options = get_option( 'sf_pa_autosuggest_plugin_options' );
        $value = '';
        if (isset($options[$params['key']]))
            $value = esc_attr( $options[$params['key']]);
        echo "<input id='".$params['section']."_".$params['key']."' name='sf_pa_autosuggest_plugin_options[".$params['key']."]' type='text' value='" .$value. "' />";
        if(isset($params['instruction']) && !empty($params['instruction'])){
            echo '<p class="sf_pa-instruction">'.$params['instruction'].'</p>';
        }
    }
    
    public function color_picker($params){
        $options = get_option( 'sf_pa_autosuggest_plugin_options' );
        $value = '';
        if (isset($options[$params['key']]))
            $value = esc_attr( $options[$params['key']]);
        echo "<input id='".$params['section']."_".$params['key']."' class='sf_pa_color_picker' name='sf_pa_autosuggest_plugin_options[".$params['key']."]' type='text' value='" .$value. "' />";
        if(isset($params['instruction']) && !empty($params['instruction'])){
            echo '<p class="sf_pa-instruction">'.$params['instruction'].'</p>';
        }
    }
    
    public function checkbox($params){
        $options = get_option( 'sf_pa_autosuggest_plugin_options' );
        $value = '';
        if (isset($options[$params['key']]) && $options[$params['key']] =='on')
            $value = 'checked';
        echo "<input id='".$params['section']."_".$params['key']."' name='sf_pa_autosuggest_plugin_options[".$params['key']."]' type='checkbox' $value />";
        
        if(isset($params['instruction']) && !empty($params['instruction'])){
            echo '<p class="sf_pa-instruction">'.$params['instruction'].'</p>';
        }
    
    }
    
    public function plugin_options_validate( $input ) {
        $validator = new SfWAValidator;
        $newinput['results_count'] = $validator->int($input['results_count'], 6);
        $newinput['all_text'] =  $validator->plaintext($input['all_text']);
        $newinput['all_bg'] =  $validator->hexadecimal($input['all_bg'], '#000');
        $newinput['all_color'] =  $validator->hexadecimal($input['all_color'], '#fff');
        $newinput['show_thumbnail'] = $validator->checkbox($input['show_thumbnail']);
        $newinput['show_cat'] = $validator->checkbox($input['show_cat']);
        $newinput['exclude_cat'] = $validator->ids($input['exclude_cat']);
        $newinput['exclude_ids'] =  $validator->ids($input['exclude_ids']);
    
        return $newinput;
    }
}
new AdminClass();